@@ -1,22 +1,4 @@
-# ##### BEGIN GPL LICENSE BLOCK #####
-#
-#  This program is free software; you can redistribute it and/or
-#  modify it under the terms of the GNU General Public License
-#  as published by the Free Software Foundation; either version 2
-#  of the License, or (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software Foundation,
-#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-#
-# ##### END GPL LICENSE BLOCK #####
-
-# <pep8-80 compliant>
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 from mathutils import Vector
 import bpy
@@ -25,9 +7,9 @@ from bpy.props import (
     BoolProperty,
     EnumProperty,
     FloatProperty,
-    FloatVectorProperty,
     IntProperty,
 )
+from bpy.app.translations import pgettext_tip as tip_
 
 
 def object_ensure_material(obj, mat_name):
@@ -195,8 +177,8 @@ class QuickExplode(ObjectModeOperator, Operator):
         for obj in mesh_objects:
             if obj.particle_systems:
                 self.report({'ERROR'},
-                            "Object %r already has a "
-                            "particle system" % obj.name)
+                            tip_("Object %r already has a "
+                                 "particle system") % obj.name)
 
                 return {'CANCELLED'}
 
@@ -442,6 +424,7 @@ class QuickSmoke(ObjectModeOperator, Operator):
 
 
 class QuickLiquid(Operator):
+    """Make selected objects liquid"""
     bl_idname = "object.quick_liquid"
     bl_label = "Quick Liquid"
     bl_options = {'REGISTER', 'UNDO'}
@@ -496,7 +479,7 @@ class QuickLiquid(Operator):
             obj_bb_minmax(obj, min_co, max_co)
 
         # add the liquid domain object
-        bpy.ops.mesh.primitive_cube_add()
+        bpy.ops.mesh.primitive_cube_add(align='WORLD')
         obj = context.active_object
         obj.name = "Liquid Domain"
 
